local AddonName, Addon = ... 
local Config = Addon.Config 
local SetWindow = Addon.SetWindow 
local L = Addon.L

function SetWindow:Initialize()
    local f = CreateFrame("Frame", nil, UIParent)
    f:SetWidth(360)
    f:SetHeight(510)
    f:SetBackdrop({
        bgFile = "Interface\\DialogFrame\\UI-DialogBox-Background",
        edgeFile = "Interface\\DialogFrame\\UI-DialogBox-Border",
        tile = true,
        tileSize = 32,
        edgeSize = 32,
        insets =
        {left = 8, right = 8, top = 10, bottom = 10}
    })
    f:SetBackdropColor(0, 0, 0)
    f:SetPoint("CENTER", 210, 0)
    f:SetToplevel(true)
    f:EnableMouse(true)
    f:SetMovable(true)
    f:RegisterForDrag("LeftButton")
    f:SetScript("OnDragStart", f.StartMoving)
    f:SetScript("OnDragStop", f.StopMovingOrSizing)
    f:SetScript("OnMouseDown", clearAllFocus)
    f:Hide()
    Addon.SetWindow = f
    do
        local t = f:CreateTexture(nil, "ARTWORK")
        t:SetTexture("Interface/DialogFrame/UI-DialogBox-Header")
        t:SetWidth(360)
        t:SetHeight(64)
        t:SetPoint("TOP", f, 0, 12)
        f.texture = t
    end
    do
        local t = f:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
        t:SetText(string.format(L["Loot Monitor v%s"], Addon.Version))
        t:SetPoint("TOP", f.texture, 0, -14)
    end
    do
        local b = CreateFrame("Button", nil, f, "GameMenuButtonTemplate")
        b:SetWidth(120)
        b:SetHeight(25)
        b:SetPoint("BOTTOMLEFT", 220, 20)
        b:SetText(CLOSE)
        b:SetScript("OnClick", function() f:Hide() end)
    end
    do
        if not Config.HasSpellWhisper then
            local t = f:CreateFontString(nil, "ARTWORK", "GameFontHighlightSmallLeft")
            t:SetText(L["Prevent Trade"])
            local c = CreateFrame("CheckButton", nil, f, "InterfaceOptionsCheckButtonTemplate")
            c:SetPoint("TOPLEFT", 200, -40)
            t:SetPoint("LEFT", c, "RIGHT", 5, 0)
            c:SetScript("OnShow", function(self) self:SetChecked(Config.PreventTrade) end)
            c:SetScript("OnClick", function(self) Config.PreventTrade = self:GetChecked() end)
        end
    end
    do
        local t = f:CreateFontString(nil, "ARTWORK", "GameFontHighlightSmallLeft")
        t:SetText(L["Output to RW"])
        local c = CreateFrame("CheckButton", nil, f, "InterfaceOptionsCheckButtonTemplate")
        c:SetPoint("TOPLEFT", 50, -40)
        t:SetPoint("LEFT", c, "RIGHT", 5, 0)
        c:SetScript("OnShow", function(self) self:SetChecked(Config.OutputToRaidWarning) end)
        c:SetScript("OnClick", function(self) Config.OutputToRaidWarning = self:GetChecked() end)
    end
    do
        local t1 = f:CreateFontString(nil, "ARTWORK", "GameFontHighlightSmallLeft")
        t1:SetPoint("TOPLEFT", f, 20, -125)
        t1:SetWidth(150)
        t1:SetHeight(360)
        local t2 = f:CreateFontString(nil, "ARTWORK", "GameFontHighlightSmallLeft")
        t2:SetPoint("TOPLEFT", f, 190, -125)
        t2:SetWidth(150)
        t2:SetHeight(360)
        local b1 = CreateFrame("Button", nil, f, "GameMenuButtonTemplate")
        b1:SetWidth(120)
        b1:SetHeight(25)
        b1:SetText(L["Check ALL"])
        b1:SetScript("OnClick", function()
            if IsInRaid() and (UnitIsGroupLeader("player") or UnitIsGroupAssistant("player")) then
                Addon:UpdateGroupInfo()
                Addon:DoCheck()
                print(L["<LM>Check LootMonitor Addon State."])
            elseif IsInRaid() then
                print(L["<LM>Can't Check because of you are not Leader or Assistant."])
            else
                print(L["<LM>Not in a Raid Team."])
            end
        end)
        local b2 = CreateFrame("Button", nil, f, "GameMenuButtonTemplate")
        b2:SetWidth(120)
        b2:SetHeight(25)
        b2:SetText(L["Print State"])
        b2:SetScript("OnClick", function()
            if IsInRaid() and (UnitIsGroupLeader("player") or UnitIsGroupAssistant("player")) then
                local msg1, msg2 = Addon:GetCheckText()
                t1:SetText(msg1)
                t2:SetText(msg2)
            elseif IsInRaid() then
                print(L["<LM>Can't Print State because of you are not Leader or Assistant."])
                t1:SetText("")
                t2:SetText("")
            else
                print(L["<LM>Not in a Raid Team."])
                t1:SetText("")
                t2:SetText("")
            end
        end)
        b1:SetPoint("TOPLEFT", 90, -115)
        b2:SetPoint("TOPLEFT", 220, -115)
    end
    do
        local d = CreateFrame("Frame", nil, f, "UIDropDownMenuTemplate")
        local t = f:CreateFontString(nil, "ARTWORK", "GameFontNormalSmallLeft")
        t:SetText(L["Quality"])
        t:SetPoint("LEFT", d, "LEFT", -60, 0)

        local value = {1, 2, 3, 4,}
        local text = {L["|cFFFFFFFFCommon|r"], L["|cFF1EFF00Uncommon|r"], L["|cFF0081FFRare|r"], L["|cFFC600FFEpic|r"],}
        UIDropDownMenu_Initialize(d, function(self)
            local info = UIDropDownMenu_CreateInfo()
            d.text = text
            for i = 1, 4 do
                info.text = text[i]
                info.value = value[i]
                info.func = function(v)
                    Config.Quality = v.value
                    UIDropDownMenu_SetText(d, text[v.value])
                    CloseDropDownMenus()
                end
                info.arg1, info.arg2 = d, value[i]
                UIDropDownMenu_AddButton(info)
            end
        end)

        d.SetValue = function(v) Config.Quality = v end
        d:SetScript("OnShow", function(self)
            UIDropDownMenu_SetText(self, self.text[Config.Quality])
        end)

        UIDropDownMenu_JustifyText(d, "CENTER")
        UIDropDownMenu_SetWidth(d, 120)
        UIDropDownMenu_SetButtonWidth(d, 120)

        d:SetPoint("TOPLEFT", 115, -75)
    end
end